/*
 * Copyright (c) 2008 by Naohide Sano, All rights reserved.
 *
 * Programmed by Naohide Sano
 */

package vavi.apps.appleii;

import java.awt.Canvas;
import java.awt.Color;
import java.awt.Dialog;
import java.awt.Graphics;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;

import junit.framework.TestCase;


/**
 * VirtualKeyboardTest.
 *
 * @author <a href="mailto:umjammer@gmail.com">Naohide Sano</a> (nsano)
 * @version 0.00 080924 nsano initial version <br>
 */
public class VirtualKeyboardTest extends TestCase {

    public void test01() throws Exception {
        char[][] keys = null;
        int neededColumns;
        int neededRows;

        keys = new char[4][];

        // numerals
        keys[0] = new char[23]; // numerals
        for (char i=0; i<10; i++) {  // 0..9
            keys[0][i] = (char)(i+48);
        }
        keys[0][10] = '=';
        keys[0][11] = '+';
        keys[0][12] = '-';
        keys[0][13] = '*';
        keys[0][14] = '/';
        keys[0][15] = '.';
        keys[0][16] = ',';
        keys[0][17] = '$';
        keys[0][18] = '%';
        keys[0][19] = '^';
        keys[0][20] = '#';
        keys[0][21] = '_';
        keys[0][22] = ' ';

        // Roman, lower case
        keys[1] = new char[51]; // numerals
        keys[1][0] = 'q';
        keys[1][1] = 'w';
        keys[1][2] = 'e';
        keys[1][3] = 'r';
        keys[1][4] = 't';
        keys[1][5] = 'y';
        keys[1][6] = 'u';
        keys[1][7] = 'i';
        keys[1][8] = 'o';
        keys[1][9] = 'p';
        keys[1][10] = '1';
        keys[1][11] = '2';
        keys[1][12] = '3';
        keys[1][13] = '0';
        keys[1][14] = '!';
        keys[1][15] = '@';
        keys[1][16] = '#';
        keys[1][17] = 'a';
        keys[1][18] = 's';
        keys[1][19] = 'd';
        keys[1][20] = 'f';
        keys[1][21] = 'g';
        keys[1][22] = 'h';
        keys[1][23] = 'j';
        keys[1][24] = 'k';
        keys[1][25] = 'l';
        keys[1][26] = ';';
        keys[1][27] = '4';
        keys[1][28] = '5';
        keys[1][29] = '6';
        keys[1][30] = '_';
        keys[1][31] = '$';
        keys[1][32] = '%';
        keys[1][33] = '^';
        keys[1][34] = 'z';
        keys[1][35] = 'x';
        keys[1][36] = 'c';
        keys[1][37] = 'v';
        keys[1][38] = 'b';
        keys[1][39] = 'n';
        keys[1][40] = 'm';
        keys[1][41] = ',';
        keys[1][42] = '.';
        keys[1][43] = ' ';// space
        keys[1][44] = '7';
        keys[1][45] = '8';
        keys[1][46] = '9';
        keys[1][47] = '?';
        keys[1][48] = '&';
        keys[1][49] = '*';
        keys[1][50] = '/';

        // Roman, upper case
        keys[2] = new char[51]; // numerals
        keys[2][0] = 'Q';
        keys[2][1] = 'W';
        keys[2][2] = 'E';
        keys[2][3] = 'R';
        keys[2][4] = 'T';
        keys[2][5] = 'Y';
        keys[2][6] = 'U';
        keys[2][7] = 'I';
        keys[2][8] = 'O';
        keys[2][9] = 'P';
        keys[2][10] = '1';
        keys[2][11] = '2';
        keys[2][12] = '3';
        keys[2][13] = '0';
        keys[2][14] = '!';
        keys[2][15] = '@';
        keys[2][16] = '#';
        keys[2][17] = 'A';
        keys[2][18] = 'S';
        keys[2][19] = 'D';
        keys[2][20] = 'F';
        keys[2][21] = 'G';
        keys[2][22] = 'H';
        keys[2][23] = 'J';
        keys[2][24] = 'K';
        keys[2][25] = 'L';
        keys[2][26] = ';';
        keys[2][27] = '4';
        keys[2][28] = '5';
        keys[2][29] = '6';
        keys[2][30] = '_';
        keys[2][31] = '$';
        keys[2][32] = '%';
        keys[2][33] = '^';
        keys[2][34] = 'Z';
        keys[2][35] = 'X';
        keys[2][36] = 'C';
        keys[2][37] = 'V';
        keys[2][38] = 'B';
        keys[2][39] = 'N';
        keys[2][40] = 'M';
        keys[2][41] = ',';
        keys[2][42] = '.';
        keys[2][43] = ' ';// space
        keys[2][44] = '7';
        keys[2][45] = '8';
        keys[2][46] = '9';
        keys[2][47] = '?';
        keys[2][48] = '&';
        keys[2][49] = '*';
        keys[2][50] = '/';

        // Symbol
        keys[3] = new char[25]; // numerals
        for (char i=0; i<15; i++) {  // !../
            keys[3][i] = (char)(i+33);
        }
        for (char i=0; i<7; i++) {  // :..@
            keys[3][i+15] = (char)(i+58);
        }
        keys[3][22] = '~'; // space
        keys[3][23] = '^'; // space
        keys[3][24] = ' '; // space

        neededColumns = 17;
        neededRows = 3;

        VirtualKeyboardListener vkl = new VirtualKeyboardListener() {
            public int getAvailableHeight() {
                return 640;
            }
            public int getAvailableWidth() {
                return 400;
            }
            public void paintCandidateBar(Graphics g, int width, int height) {
                g.setColor(Color.pink);
                g.fillRect(0, 0, width, height);
            }
            public void paintTextOnly(Graphics g, int width, int height) {
                g.setColor(Color.blue);
                g.fillRect(0, 0, width, height);
            }
            public void repaintVK() {
            }
            public void virtualKeyEntered(int type, char c) {
            }
            public void virtualMetaKeyEntered(int metaKey) {
            }
        };

        Dialog dialog = new Dialog(null, true);
        final VirtualKeyboard virtualKeyboard = new VirtualKeyboard(keys, vkl, true, neededColumns, neededRows);
        Canvas canvas = new Canvas() {
            public void paint(Graphics g) {
                virtualKeyboard.paint(g);
                super.paint(g);
            }
        };
        canvas.setSize(640, 400);
        dialog.add(canvas);
        dialog.pack();
        dialog.show();
    }

    public void $test02() throws Exception {
        byte[][] bs = {
            ok,
            cancel,
            backspace,
            shift,
            caps,
            mode,
            cn
        };
        String[] names = {
            "ok.png",
            "cancel.png",
            "backspace.png",
            "shift.png",
            "caps.png",
            "mode.png",
            "cn.png"
        };
        for (int i = 0; i < names.length; i++) {
            x(names[i], bs[i]);
        }
    }

    private void x(String name, byte[] b) throws IOException {
        OutputStream os = new FileOutputStream(name);
        os.write(b, 0, b.length);
        os.flush();
        os.close();
    }

    /** backspace.png */
    private byte[] backspace = {
        (byte) 0x89, (byte) 0x50, (byte) 0x4e, (byte) 0x47, (byte) 0x0d, (byte) 0x0a, (byte) 0x1a, (byte) 0x0a, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x0d, (byte) 0x49, (byte) 0x48, (byte) 0x44, (byte) 0x52, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x0d, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x0d, (byte) 0x08, (byte) 0x03, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x45, (byte) 0x35, (byte) 0x14, (byte) 0x4e, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x04, (byte) 0x67,
        (byte) 0x41, (byte) 0x4d, (byte) 0x41, (byte) 0x00, (byte) 0x00, (byte) 0xb1, (byte) 0x8e, (byte) 0x7c, (byte) 0xfb, (byte) 0x51, (byte) 0x93, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x20, (byte) 0x63, (byte) 0x48, (byte) 0x52, (byte) 0x4d, (byte) 0x00, (byte) 0x00, (byte) 0x7a, (byte) 0x25, (byte) 0x00, (byte) 0x00, (byte) 0x80, (byte) 0x83, (byte) 0x00, (byte) 0x00, (byte) 0xf9, (byte) 0xff, (byte) 0x00, (byte) 0x00, (byte) 0x80, (byte) 0xe6, (byte) 0x00, (byte) 0x00, (byte) 0x75,
        (byte) 0x2e, (byte) 0x00, (byte) 0x00, (byte) 0xea, (byte) 0x5f, (byte) 0x00, (byte) 0x00, (byte) 0x3a, (byte) 0x97, (byte) 0x00, (byte) 0x00, (byte) 0x17, (byte) 0x6f, (byte) 0x69, (byte) 0xe4, (byte) 0xc4, (byte) 0x2b, (byte) 0x00, (byte) 0x00, (byte) 0x03, (byte) 0x00, (byte) 0x50, (byte) 0x4c, (byte) 0x54, (byte) 0x45, (byte) 0xe6, (byte) 0xe6, (byte) 0xe6, (byte) 0xcc, (byte) 0xcc, (byte) 0xcc, (byte) 0xa6, (byte) 0xa6, (byte) 0xa6, (byte) 0x80, (byte) 0x80, (byte) 0x80, (byte) 0xff,
        (byte) 0xff, (byte) 0xff, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x1b, (byte) 0xff, (byte) 0xdb, (byte) 0xbb, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x05, (byte) 0x74, (byte) 0x52, (byte) 0x4e, (byte) 0x53, (byte) 0xff, (byte) 0xff, (byte) 0xff, (byte) 0xff, (byte) 0x00, (byte) 0xfb, (byte) 0xb6, (byte) 0x0e, (byte) 0x53, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x70, (byte) 0x49, (byte) 0x44, (byte) 0x41, (byte) 0x54, (byte) 0x78, (byte) 0x9c, (byte) 0x62, (byte) 0x60, (byte) 0x41, (byte) 0x06, (byte) 0x00, (byte) 0x01, (byte) 0xc4, (byte) 0x80, (byte) 0xc2, (byte) 0x03, (byte) 0x08, (byte) 0x20,
        (byte) 0x30, (byte) 0x8f, (byte) 0x11, (byte) 0x0a, (byte) 0x98, (byte) 0x01, (byte) 0x02, (byte) 0x08, (byte) 0xc4, (byte) 0x63, (byte) 0x64, (byte) 0x80, (byte) 0x02, (byte) 0x66, (byte) 0x80, (byte) 0x00, (byte) 0x62, (byte) 0x00, (byte) 0x73, (byte) 0x98, (byte) 0x81, (byte) 0x4c, (byte) 0x26, (byte) 0x20, (byte) 0x05, (byte) 0x10, (byte) 0x40, (byte) 0x0c, (byte) 0x10, (byte) 0x19, (byte) 0x66, (byte) 0x10, (byte) 0x87, (byte) 0x81, (byte) 0x19, (byte) 0x20, (byte) 0x80, (byte) 0x18,
        (byte) 0x18, (byte) 0x61, (byte) 0x8a, (byte) 0x40, (byte) 0x04, (byte) 0x40, (byte) 0x00, (byte) 0x31, (byte) 0xb0, (byte) 0x80, (byte) 0x69, (byte) 0x26, (byte) 0x30, (byte) 0x97, (byte) 0x19, (byte) 0x20, (byte) 0x80, (byte) 0x80, (byte) 0xfa, (byte) 0x98, (byte) 0x19, (byte) 0xa0, (byte) 0xca, (byte) 0x18, (byte) 0x98, (byte) 0x01, (byte) 0x02, (byte) 0x08, (byte) 0x64, (byte) 0x26, (byte) 0x33, (byte) 0xdc, (byte) 0x4c, (byte) 0x80, (byte) 0x00, (byte) 0x02, (byte) 0xdb, (byte) 0x07,
        (byte) 0xe3, (byte) 0x32, (byte) 0x03, (byte) 0x04, (byte) 0x10, (byte) 0xc4, (byte) 0x2d, (byte) 0xcc, (byte) 0x50, (byte) 0x00, (byte) 0x10, (byte) 0x40, (byte) 0xa8, (byte) 0x2e, (byte) 0x03, (byte) 0x08, (byte) 0x30, (byte) 0x00, (byte) 0x82, (byte) 0x47, (byte) 0x01, (byte) 0x63, (byte) 0x1f, (byte) 0x9e, (byte) 0x42, (byte) 0x65, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x49, (byte) 0x45, (byte) 0x4e, (byte) 0x44, (byte) 0xae, (byte) 0x42, (byte) 0x60, (byte) 0x82
    };

    /** cancel.png */
    private byte[] cancel = {
        (byte) 0x89, (byte) 0x50, (byte) 0x4e, (byte) 0x47, (byte) 0x0d, (byte) 0x0a, (byte) 0x1a, (byte) 0x0a, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x0d, (byte) 0x49, (byte) 0x48, (byte) 0x44, (byte) 0x52, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x0d, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x0d, (byte) 0x08, (byte) 0x06, (byte) 0x00, (byte) 0x00, (byte) 0x01, (byte) 0x05, (byte) 0xec, (byte) 0xd4, (byte) 0xea, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x04, (byte) 0x67,
        (byte) 0x41, (byte) 0x4d, (byte) 0x41, (byte) 0x00, (byte) 0x00, (byte) 0xaf, (byte) 0xc8, (byte) 0x37, (byte) 0x05, (byte) 0x8a, (byte) 0xe9, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x19, (byte) 0x74, (byte) 0x45, (byte) 0x58, (byte) 0x74, (byte) 0x53, (byte) 0x6f, (byte) 0x66, (byte) 0x74, (byte) 0x77, (byte) 0x61, (byte) 0x72, (byte) 0x65, (byte) 0x00, (byte) 0x41, (byte) 0x64, (byte) 0x6f, (byte) 0x62, (byte) 0x65, (byte) 0x20, (byte) 0x49, (byte) 0x6d, (byte) 0x61, (byte) 0x67,
        (byte) 0x65, (byte) 0x52, (byte) 0x65, (byte) 0x61, (byte) 0x64, (byte) 0x79, (byte) 0x71, (byte) 0xc9, (byte) 0x65, (byte) 0x3c, (byte) 0x00, (byte) 0x00, (byte) 0x01, (byte) 0x05, (byte) 0x49, (byte) 0x44, (byte) 0x41, (byte) 0x54, (byte) 0x78, (byte) 0xda, (byte) 0x62, (byte) 0xfc, (byte) 0xff, (byte) 0xff, (byte) 0x3f, (byte) 0x03, (byte) 0x08, (byte) 0x00, (byte) 0x04, (byte) 0x10, (byte) 0x03, (byte) 0x88, (byte) 0xc1, (byte) 0xc4, (byte) 0xc4, (byte) 0xf4, (byte) 0x1e, (byte) 0x20,
        (byte) 0x80, (byte) 0x18, (byte) 0x61, (byte) 0x22, (byte) 0x00, (byte) 0x01, (byte) 0x04, (byte) 0xe6, (byte) 0x81, (byte) 0x38, (byte) 0x00, (byte) 0x01, (byte) 0x04, (byte) 0x93, (byte) 0xfa, (byte) 0x0f, (byte) 0xc2, (byte) 0x20, (byte) 0x36, (byte) 0x40, (byte) 0x00, (byte) 0x21, (byte) 0x94, (byte) 0x40, (byte) 0x01, (byte) 0x40, (byte) 0x00, (byte) 0xa1, (byte) 0x08, (byte) 0x00, (byte) 0x04, (byte) 0x10, (byte) 0x23, (byte) 0x50, (byte) 0x19, (byte) 0x9c, (byte) 0x03, (byte) 0x10,
        (byte) 0x40, (byte) 0x2c, (byte) 0x50, (byte) 0x5a, (byte) 0x00, (byte) 0x88, (byte) 0x0d, (byte) 0x00, (byte) 0x02, (byte) 0x08, (byte) 0x45, (byte) 0x19, (byte) 0x40, (byte) 0x00, (byte) 0xc1, (byte) 0x4c, (byte) 0x05, (byte) 0xe1, (byte) 0x7a, (byte) 0x28, (byte) 0x0d, (byte) 0xc6, (byte) 0x20, (byte) 0x71, (byte) 0x80, (byte) 0x00, (byte) 0x02, (byte) 0xab, (byte) 0x64, (byte) 0x66, (byte) 0x66, (byte) 0x86, (byte) 0xab, (byte) 0x05, (byte) 0x99, (byte) 0x0b, (byte) 0x62, (byte) 0xfc,
        (byte) 0xfd, (byte) 0xfb, (byte) 0x97, (byte) 0x01, (byte) 0x20, (byte) 0x80, (byte) 0x30, (byte) 0xac, (byte) 0x47, (byte) 0x06, (byte) 0x00, (byte) 0x01, (byte) 0x84, (byte) 0x53, (byte) 0x12, (byte) 0x20, (byte) 0x80, (byte) 0x60, (byte) 0xf6, (byte) 0x09, (byte) 0x20, (byte) 0xd9, (byte) 0x65, (byte) 0x00, (byte) 0xa2, (byte) 0x01, (byte) 0x02, (byte) 0x88, (byte) 0x09, (byte) 0xc9, (byte) 0x89, (byte) 0xfd, (byte) 0x40, (byte) 0xbc, (byte) 0x1f, (byte) 0xe4, (byte) 0x54, (byte) 0x90,
        (byte) 0x00, (byte) 0x40, (byte) 0x00, (byte) 0xc1, (byte) 0x24, (byte) 0x1e, (byte) 0x00, (byte) 0xb1, (byte) 0x02, (byte) 0x10, (byte) 0x1f, (byte) 0x00, (byte) 0xe2, (byte) 0x05, (byte) 0x20, (byte) 0x01, (byte) 0x80, (byte) 0x00, (byte) 0x82, (byte) 0x79, (byte) 0xca, (byte) 0x01, (byte) 0xaa, (byte) 0x2b, (byte) 0x00, (byte) 0xca, (byte) 0x9f, (byte) 0x08, (byte) 0x10, (byte) 0x40, (byte) 0x38, (byte) 0x2d, (byte) 0x07, (byte) 0x08, (byte) 0x20, (byte) 0x26, (byte) 0x5c, (byte) 0xce,
        (byte) 0x05, (byte) 0x08, (byte) 0x20, (byte) 0xbc, (byte) 0x7e, (byte) 0xc1, (byte) 0x05, (byte) 0x00, (byte) 0x02, (byte) 0x08, (byte) 0xec, (byte) 0x15, (byte) 0xb4, (byte) 0xe0, (byte) 0xfb, (byte) 0x8f, (byte) 0xe4, (byte) 0x35, (byte) 0x10, (byte) 0xbd, (byte) 0x1f, (byte) 0x2a, (byte) 0x56, (byte) 0x00, (byte) 0x0b, (byte) 0x52, (byte) 0x80, (byte) 0x00, (byte) 0x42, (byte) 0xd7, (byte) 0x04, (byte) 0xc2, (byte) 0x09, (byte) 0x50, (byte) 0x45, (byte) 0x30, (byte) 0xc5, (byte) 0x01,
        (byte) 0xe8, (byte) 0xf1, (byte) 0x00, (byte) 0x10, (byte) 0x40, (byte) 0xd8, (byte) 0xdc, (byte) 0x7d, (byte) 0x01, (byte) 0x88, (byte) 0x3f, (byte) 0x40, (byte) 0xc3, (byte) 0xe8, (byte) 0x03, (byte) 0x34, (byte) 0x78, (byte) 0x50, (byte) 0x00, (byte) 0x40, (byte) 0x00, (byte) 0x21, (byte) 0xdb, (byte) 0x04, (byte) 0xb2, (byte) 0xe1, (byte) 0x3d, (byte) 0x10, (byte) 0xaf, (byte) 0x47, (byte) 0x0b, (byte) 0xf9, (byte) 0x7e, (byte) 0xa8, (byte) 0x8d, (byte) 0xeb, (byte) 0x61, (byte) 0x36,
        (byte) 0x01, (byte) 0x04, (byte) 0x10, (byte) 0x59, (byte) 0x01, (byte) 0x01, (byte) 0x10, (byte) 0x60, (byte) 0x00, (byte) 0x1b, (byte) 0x87, (byte) 0x6f, (byte) 0x18, (byte) 0x70, (byte) 0x09, (byte) 0x02, (byte) 0x0d, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x49, (byte) 0x45, (byte) 0x4e, (byte) 0x44, (byte) 0xae, (byte) 0x42, (byte) 0x60, (byte) 0x82
    };

    /** caps.png */
    private byte[] caps = {
        (byte) 0x89, (byte) 0x50, (byte) 0x4e, (byte) 0x47, (byte) 0x0d, (byte) 0x0a, (byte) 0x1a, (byte) 0x0a, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x0d, (byte) 0x49, (byte) 0x48, (byte) 0x44, (byte) 0x52, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x0d, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x0d, (byte) 0x08, (byte) 0x03, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x45, (byte) 0x35, (byte) 0x14, (byte) 0x4e, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x04, (byte) 0x67,
        (byte) 0x41, (byte) 0x4d, (byte) 0x41, (byte) 0x00, (byte) 0x00, (byte) 0xb1, (byte) 0x8e, (byte) 0x7c, (byte) 0xfb, (byte) 0x51, (byte) 0x93, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x20, (byte) 0x63, (byte) 0x48, (byte) 0x52, (byte) 0x4d, (byte) 0x00, (byte) 0x00, (byte) 0x7a, (byte) 0x25, (byte) 0x00, (byte) 0x00, (byte) 0x80, (byte) 0x83, (byte) 0x00, (byte) 0x00, (byte) 0xf9, (byte) 0xff, (byte) 0x00, (byte) 0x00, (byte) 0x80, (byte) 0xe6, (byte) 0x00, (byte) 0x00, (byte) 0x75,
        (byte) 0x2e, (byte) 0x00, (byte) 0x00, (byte) 0xea, (byte) 0x5f, (byte) 0x00, (byte) 0x00, (byte) 0x3a, (byte) 0x97, (byte) 0x00, (byte) 0x00, (byte) 0x17, (byte) 0x6f, (byte) 0x69, (byte) 0xe4, (byte) 0xc4, (byte) 0x2b, (byte) 0x00, (byte) 0x00, (byte) 0x03, (byte) 0x00, (byte) 0x50, (byte) 0x4c, (byte) 0x54, (byte) 0x45, (byte) 0xe6, (byte) 0xe6, (byte) 0xe6, (byte) 0xcc, (byte) 0xcc, (byte) 0xcc, (byte) 0x7d, (byte) 0x7d, (byte) 0x7d, (byte) 0xff, (byte) 0xff, (byte) 0xff, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0xa0, (byte) 0xe5, (byte) 0xcc, (byte) 0x14, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x04, (byte) 0x74, (byte) 0x52, (byte) 0x4e, (byte) 0x53, (byte) 0xff, (byte) 0xff, (byte) 0xff, (byte) 0x00, (byte) 0x40, (byte) 0x2a, (byte) 0xa9, (byte) 0xf4, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x65, (byte) 0x49, (byte) 0x44, (byte) 0x41, (byte) 0x54, (byte) 0x78, (byte) 0x9c, (byte) 0x62, (byte) 0x60, (byte) 0x06, (byte) 0x03, (byte) 0x46, (byte) 0x08, (byte) 0x05, (byte) 0x10, (byte) 0x40, (byte) 0x0c, (byte) 0x10, (byte) 0x0e, (byte) 0x03,
        (byte) 0x13, (byte) 0x98, (byte) 0x06, (byte) 0x08, (byte) 0x20, (byte) 0x06, (byte) 0x08, (byte) 0x87, (byte) 0x01, (byte) 0xc2, (byte) 0x05, (byte) 0x08, (byte) 0x20, (byte) 0x06, (byte) 0x28, (byte) 0x07, (byte) 0xc2, (byte) 0x05, (byte) 0x08, (byte) 0x20, (byte) 0x06, (byte) 0x18, (byte) 0x07, (byte) 0xcc, (byte) 0x05, (byte) 0x08, (byte) 0x20, (byte) 0x06, (byte) 0x38, (byte) 0x07, (byte) 0xc4, (byte) 0x05, (byte) 0x08, (byte) 0x20, (byte) 0x06, (byte) 0x46, (byte) 0x26, (byte) 0x26,
        (byte) 0x26, (byte) 0xb0, (byte) 0x3e, (byte) 0x10, (byte) 0x00, (byte) 0x08, (byte) 0x20, (byte) 0x54, (byte) 0x53, (byte) 0x00, (byte) 0x02, (byte) 0x08, (byte) 0xc2, (byte) 0x03, (byte) 0x89, (byte) 0x83, (byte) 0x18, (byte) 0x00, (byte) 0x01, (byte) 0x04, (byte) 0xb1, (byte) 0x0f, (byte) 0x06, (byte) 0x00, (byte) 0x02, (byte) 0x08, (byte) 0x22, (byte) 0x07, (byte) 0x02, (byte) 0x20, (byte) 0x06, (byte) 0x40, (byte) 0x00, (byte) 0xa1, (byte) 0xea, (byte) 0x03, (byte) 0x08, (byte) 0x20,
        (byte) 0x54, (byte) 0x7d, (byte) 0x00, (byte) 0x01, (byte) 0x06, (byte) 0x00, (byte) 0x78, (byte) 0xe7, (byte) 0x01, (byte) 0x5d, (byte) 0x6f, (byte) 0x06, (byte) 0x04, (byte) 0xbf, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x49, (byte) 0x45, (byte) 0x4e, (byte) 0x44, (byte) 0xae, (byte) 0x42, (byte) 0x60, (byte) 0x82
    };

    /** mode.png */
    private byte[] mode = {
        (byte) 0x89, (byte) 0x50, (byte) 0x4e, (byte) 0x47, (byte) 0x0d, (byte) 0x0a, (byte) 0x1a, (byte) 0x0a, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x0d, (byte) 0x49, (byte) 0x48, (byte) 0x44, (byte) 0x52, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x0d, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x0d, (byte) 0x08, (byte) 0x06, (byte) 0x00, (byte) 0x00, (byte) 0x01, (byte) 0x05, (byte) 0xec, (byte) 0xd4, (byte) 0xea, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x04, (byte) 0x67,
        (byte) 0x41, (byte) 0x4d, (byte) 0x41, (byte) 0x00, (byte) 0x00, (byte) 0xaf, (byte) 0xc8, (byte) 0x37, (byte) 0x05, (byte) 0x8a, (byte) 0xe9, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x19, (byte) 0x74, (byte) 0x45, (byte) 0x58, (byte) 0x74, (byte) 0x53, (byte) 0x6f, (byte) 0x66, (byte) 0x74, (byte) 0x77, (byte) 0x61, (byte) 0x72, (byte) 0x65, (byte) 0x00, (byte) 0x41, (byte) 0x64, (byte) 0x6f, (byte) 0x62, (byte) 0x65, (byte) 0x20, (byte) 0x49, (byte) 0x6d, (byte) 0x61, (byte) 0x67,
        (byte) 0x65, (byte) 0x52, (byte) 0x65, (byte) 0x61, (byte) 0x64, (byte) 0x79, (byte) 0x71, (byte) 0xc9, (byte) 0x65, (byte) 0x3c, (byte) 0x00, (byte) 0x00, (byte) 0x01, (byte) 0x3a, (byte) 0x49, (byte) 0x44, (byte) 0x41, (byte) 0x54, (byte) 0x78, (byte) 0xda, (byte) 0x62, (byte) 0x60, (byte) 0x80, (byte) 0x00, (byte) 0x11, (byte) 0x80, (byte) 0x00, (byte) 0x82, (byte) 0xd2, (byte) 0x0c, (byte) 0x8b, (byte) 0x01, (byte) 0x02, (byte) 0x08, (byte) 0xc6, (byte) 0x60, (byte) 0x00, (byte) 0x08,
        (byte) 0x20, (byte) 0x10, (byte) 0xba, (byte) 0x0c, (byte) 0x22, (byte) 0x00, (byte) 0x02, (byte) 0x08, (byte) 0x03, (byte) 0x01, (byte) 0x04, (byte) 0x10, (byte) 0x32, (byte) 0x3a, (byte) 0x09, (byte) 0x22, (byte) 0x00, (byte) 0x02, (byte) 0x08, (byte) 0x84, (byte) 0xe2, (byte) 0x81, (byte) 0xb8, (byte) 0x17, (byte) 0xc4, (byte) 0x00, (byte) 0x08, (byte) 0x20, (byte) 0x26, (byte) 0x20, (byte) 0x8e, (byte) 0x05, (byte) 0xe2, (byte) 0x8f, (byte) 0x20, (byte) 0x0e, (byte) 0x40, (byte) 0x00,
        (byte) 0xa1, (byte) 0x20, (byte) 0x80, (byte) 0x00, (byte) 0x62, (byte) 0x06, (byte) 0xe2, (byte) 0x7d, (byte) 0x40, (byte) 0xdc, (byte) 0x0a, (byte) 0xc4, (byte) 0xff, (byte) 0x00, (byte) 0x02, (byte) 0x08, (byte) 0x26, (byte) 0xb8, (byte) 0x07, (byte) 0x88, (byte) 0xd5, (byte) 0xa1, (byte) 0xec, (byte) 0x7b, (byte) 0x30, (byte) 0x41, (byte) 0x80, (byte) 0x00, (byte) 0xc2, (byte) 0x8b, (byte) 0x00, (byte) 0x02, (byte) 0x88, (byte) 0x19, (byte) 0x89, (byte) 0x1d, (byte) 0x03, (byte) 0xc4,
        (byte) 0x2f, (byte) 0x81, (byte) 0x78, (byte) 0x06, (byte) 0x10, (byte) 0x73, (byte) 0x03, (byte) 0xf1, (byte) 0x25, (byte) 0x80, (byte) 0x00, (byte) 0x42, (byte) 0xf6, (byte) 0x0c, (byte) 0xc8, (byte) 0xd8, (byte) 0x3a, (byte) 0x98, (byte) 0x4a, (byte) 0x80, (byte) 0x00, (byte) 0x02, (byte) 0x21, (byte) 0x5f, (byte) 0x28, (byte) 0xdd, (byte) 0x8b, (byte) 0x2c, (byte) 0x08, (byte) 0x10, (byte) 0x40, (byte) 0xcc, (byte) 0x50, (byte) 0x95, (byte) 0xb7, (byte) 0x80, (byte) 0xf8, (byte) 0x0b,
        (byte) 0x10, (byte) 0x73, (byte) 0x01, (byte) 0xf1, (byte) 0x5b, (byte) 0x90, (byte) 0x04, (byte) 0x40, (byte) 0x00, (byte) 0xe1, (byte) 0x44, (byte) 0x00, (byte) 0x01, (byte) 0x84, (byte) 0x8c, (byte) 0x5c, (byte) 0x91, (byte) 0x1c, (byte) 0x72, (byte) 0x19, (byte) 0x20, (byte) 0x80, (byte) 0x98, (byte) 0xa0, (byte) 0x9c, (byte) 0x16, (byte) 0x20, (byte) 0x9e, (byte) 0x0e, (byte) 0x65, (byte) 0x5b, (byte) 0x00, (byte) 0xf1, (byte) 0x41, (byte) 0x80, (byte) 0x00, (byte) 0x62, (byte) 0x46,
        (byte) 0xb2, (byte) 0xeb, (byte) 0x01, (byte) 0x10, (byte) 0xf3, (byte) 0x02, (byte) 0xb1, (byte) 0x39, (byte) 0x10, (byte) 0x2b, (byte) 0x03, (byte) 0x04, (byte) 0x10, (byte) 0xcc, (byte) 0x55, (byte) 0xcb, (byte) 0xa0, (byte) 0x21, (byte) 0x01, (byte) 0x73, (byte) 0x36, (byte) 0x8c, (byte) 0x6d, (byte) 0x05, (byte) 0xc4, (byte) 0x47, (byte) 0xd1, (byte) 0xed, (byte) 0x04, (byte) 0x08, (byte) 0x20, (byte) 0x64, (byte) 0xef, (byte) 0xec, (byte) 0xc1, (byte) 0x22, (byte) 0x0e, (byte) 0xf2,
        (byte) 0x5e, (byte) 0x01, (byte) 0xba, (byte) 0x20, (byte) 0x40, (byte) 0x00, (byte) 0xc1, (byte) 0xbc, (byte) 0x19, (byte) 0x0c, (byte) 0xc4, (byte) 0x5a, (byte) 0x40, (byte) 0xfc, (byte) 0x03, (byte) 0x1a, (byte) 0x62, (byte) 0x3b, (byte) 0x81, (byte) 0x38, (byte) 0x10, (byte) 0x88, (byte) 0x25, (byte) 0x80, (byte) 0x58, (byte) 0x0d, (byte) 0x88, (byte) 0xef, (byte) 0x00, (byte) 0xf1, (byte) 0x63, (byte) 0x98, (byte) 0x26, (byte) 0x80, (byte) 0x00, (byte) 0x62, (byte) 0xc4, (byte) 0x62,
        (byte) 0x3a, (byte) 0xc8, (byte) 0xa7, (byte) 0x4b, (byte) 0xa0, (byte) 0x6c, (byte) 0x71, (byte) 0x20, (byte) 0xae, (byte) 0x85, (byte) 0x6a, (byte) 0x02, (byte) 0x81, (byte) 0xab, (byte) 0x40, (byte) 0xbc, (byte) 0x1b, (byte) 0x20, (byte) 0x80, (byte) 0x98, (byte) 0xb0, (byte) 0x68, (byte) 0x78, (byte) 0x09, (byte) 0x8d, (byte) 0x7a, (byte) 0x06, (byte) 0x28, (byte) 0x9b, (byte) 0x1f, (byte) 0x88, (byte) 0xdf, (byte) 0x00, (byte) 0xf1, (byte) 0x7e, (byte) 0x20, (byte) 0x8e, (byte) 0x03,
        (byte) 0x09, (byte) 0x02, (byte) 0x04, (byte) 0x10, (byte) 0xb2, (byte) 0x26, (byte) 0x7d, (byte) 0x68, (byte) 0xca, (byte) 0xdb, (byte) 0x0d, (byte) 0xc4, (byte) 0xc7, (byte) 0xa0, (byte) 0xc1, (byte) 0x89, (byte) 0x0c, (byte) 0x2e, (byte) 0xc2, (byte) 0x0c, (byte) 0x06, (byte) 0x08, (byte) 0x30, (byte) 0x00, (byte) 0x84, (byte) 0x8e, (byte) 0x2c, (byte) 0x30, (byte) 0x86, (byte) 0x31, (byte) 0xc1, (byte) 0x68, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x49, (byte) 0x45,
        (byte) 0x4e, (byte) 0x44, (byte) 0xae, (byte) 0x42, (byte) 0x60, (byte) 0x82
    };

    /** ok.png */
    private byte[] ok = {
        (byte) 0x89, (byte) 0x50, (byte) 0x4e, (byte) 0x47, (byte) 0x0d, (byte) 0x0a, (byte) 0x1a, (byte) 0x0a, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x0d, (byte) 0x49, (byte) 0x48, (byte) 0x44, (byte) 0x52, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x0d, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x0d, (byte) 0x08, (byte) 0x06, (byte) 0x00, (byte) 0x00, (byte) 0x01, (byte) 0x05, (byte) 0xec, (byte) 0xd4, (byte) 0xea, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x04, (byte) 0x67,
        (byte) 0x41, (byte) 0x4d, (byte) 0x41, (byte) 0x00, (byte) 0x00, (byte) 0xaf, (byte) 0xc8, (byte) 0x37, (byte) 0x05, (byte) 0x8a, (byte) 0xe9, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x19, (byte) 0x74, (byte) 0x45, (byte) 0x58, (byte) 0x74, (byte) 0x53, (byte) 0x6f, (byte) 0x66, (byte) 0x74, (byte) 0x77, (byte) 0x61, (byte) 0x72, (byte) 0x65, (byte) 0x00, (byte) 0x41, (byte) 0x64, (byte) 0x6f, (byte) 0x62, (byte) 0x65, (byte) 0x20, (byte) 0x49, (byte) 0x6d, (byte) 0x61, (byte) 0x67,
        (byte) 0x65, (byte) 0x52, (byte) 0x65, (byte) 0x61, (byte) 0x64, (byte) 0x79, (byte) 0x71, (byte) 0xc9, (byte) 0x65, (byte) 0x3c, (byte) 0x00, (byte) 0x00, (byte) 0x01, (byte) 0x05, (byte) 0x49, (byte) 0x44, (byte) 0x41, (byte) 0x54, (byte) 0x78, (byte) 0xda, (byte) 0x62, (byte) 0xf8, (byte) 0xff, (byte) 0xff, (byte) 0x3f, (byte) 0x03, (byte) 0x13, (byte) 0x13, (byte) 0x13, (byte) 0x03, (byte) 0x40, (byte) 0x00, (byte) 0x31, (byte) 0x31, (byte) 0x40, (byte) 0x01, (byte) 0x40, (byte) 0x00,
        (byte) 0x31, (byte) 0x82, (byte) 0x78, (byte) 0x40, (byte) 0xe0, (byte) 0x00, (byte) 0x10, (byte) 0x40, (byte) 0x20, (byte) 0x61, (byte) 0x03, (byte) 0x10, (byte) 0x07, (byte) 0x20, (byte) 0x80, (byte) 0x18, (byte) 0xe0, (byte) 0x6a, (byte) 0x98, (byte) 0x98, (byte) 0xee, (byte) 0x83, (byte) 0x68, (byte) 0x80, (byte) 0x00, (byte) 0x62, (byte) 0x04, (byte) 0x09, (byte) 0x20, (byte) 0x03, (byte) 0x80, (byte) 0x00, (byte) 0x82, (byte) 0xe9, (byte) 0x01, (byte) 0x03, (byte) 0x80, (byte) 0x00,
        (byte) 0x62, (byte) 0x42, (byte) 0x96, (byte) 0x01, (byte) 0x08, (byte) 0x20, (byte) 0x66, (byte) 0x46, (byte) 0x46, (byte) 0xc6, (byte) 0x7a, (byte) 0x90, (byte) 0x0a, (byte) 0x20, (byte) 0x7e, (byte) 0x00, (byte) 0x10, (byte) 0x40, (byte) 0x28, (byte) 0xfa, (byte) 0x00, (byte) 0x02, (byte) 0x08, (byte) 0xd9, (byte) 0x54, (byte) 0x64, (byte) 0x7c, (byte) 0x1e, (byte) 0x44, (byte) 0x03, (byte) 0x04, (byte) 0x10, (byte) 0x4c, (byte) 0xd2, (byte) 0x00, (byte) 0x2a, (byte) 0xb8, (byte) 0x1f,
        (byte) 0x59, (byte) 0x11, (byte) 0x40, (byte) 0x00, (byte) 0x81, (byte) 0x8d, (byte) 0x61, (byte) 0x66, (byte) 0x66, (byte) 0x06, (byte) 0x1b, (byte) 0x02, (byte) 0x35, (byte) 0x1b, (byte) 0x0e, (byte) 0x00, (byte) 0x02, (byte) 0x08, (byte) 0xc5, (byte) 0x29, (byte) 0xc8, (byte) 0x00, (byte) 0x20, (byte) 0x80, (byte) 0x58, (byte) 0xb0, (byte) 0x88, (byte) 0x19, (byte) 0x80, (byte) 0x08, (byte) 0x80, (byte) 0x00, (byte) 0x62, (byte) 0xc2, (byte) 0x26, (byte) 0x08, (byte) 0x04, (byte) 0x17,
        (byte) 0x00, (byte) 0x02, (byte) 0x08, (byte) 0x5d, (byte) 0xc2, (byte) 0x1f, (byte) 0x24, (byte) 0x08, (byte) 0x62, (byte) 0x00, (byte) 0x04, (byte) 0x10, (byte) 0xcc, (byte) 0xa8, (byte) 0xf7, (byte) 0x40, (byte) 0x2c, (byte) 0x80, (byte) 0xec, (byte) 0x00, (byte) 0x80, (byte) 0x00, (byte) 0x82, (byte) 0xe9, (byte) 0x58, (byte) 0x00, (byte) 0xc4, (byte) 0x8e, (byte) 0xc8, (byte) 0x5a, (byte) 0x01, (byte) 0x02, (byte) 0x08, (byte) 0x23, (byte) 0xc4, (byte) 0x60, (byte) 0x00, (byte) 0x20,
        (byte) 0x80, (byte) 0x90, (byte) 0xfd, (byte) 0x42, (byte) 0x08, (byte) 0x80, (byte) 0xac, (byte) 0xea, (byte) 0x07, (byte) 0xe2, (byte) 0x8d, (byte) 0x00, (byte) 0x01, (byte) 0x84, (byte) 0x2b, (byte) 0xe8, (byte) 0x90, (byte) 0xb1, (byte) 0x01, (byte) 0x34, (byte) 0xb2, (byte) 0x60, (byte) 0x21, (byte) 0xc8, (byte) 0x00, (byte) 0x10, (byte) 0x40, (byte) 0x4c, (byte) 0x04, (byte) 0x4c, (byte) 0x86, (byte) 0x79, (byte) 0x46, (byte) 0x11, (byte) 0xe6, (byte) 0x4b, (byte) 0x10, (byte) 0x00,
        (byte) 0x08, (byte) 0x20, (byte) 0x98, (byte) 0x4d, (byte) 0x0e, (byte) 0x40, (byte) 0xfc, (byte) 0x1f, (byte) 0x88, (byte) 0x0b, (byte) 0xa0, (byte) 0xa6, (byte) 0xd5, (byte) 0xc3, (byte) 0x22, (byte) 0x0a, (byte) 0x1b, (byte) 0x06, (byte) 0x08, (byte) 0x20, (byte) 0x64, (byte) 0xe7, (byte) 0x09, (byte) 0x00, (byte) 0xf1, (byte) 0x7b, (byte) 0x28, (byte) 0x5e, (byte) 0x8f, (byte) 0xcf, (byte) 0xc9, (byte) 0x00, (byte) 0x01, (byte) 0x84, (byte) 0x1e, (byte) 0x10, (byte) 0x06, (byte) 0x50,
        (byte) 0xe7, (byte) 0x1c, (byte) 0xc0, (byte) 0x17, (byte) 0x22, (byte) 0x00, (byte) 0x01, (byte) 0x06, (byte) 0x00, (byte) 0x3b, (byte) 0x85, (byte) 0x3d, (byte) 0x34, (byte) 0xf3, (byte) 0xcf, (byte) 0x64, (byte) 0xe7, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x49, (byte) 0x45, (byte) 0x4e, (byte) 0x44, (byte) 0xae, (byte) 0x42, (byte) 0x60, (byte) 0x82
    };

    /** shift.png */
    private byte[] shift = {
        (byte) 0x89, (byte) 0x50, (byte) 0x4e, (byte) 0x47, (byte) 0x0d, (byte) 0x0a, (byte) 0x1a, (byte) 0x0a, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x0d, (byte) 0x49, (byte) 0x48, (byte) 0x44, (byte) 0x52, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x0d, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x0d, (byte) 0x08, (byte) 0x03, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x45, (byte) 0x35, (byte) 0x14, (byte) 0x4e, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x04, (byte) 0x67,
        (byte) 0x41, (byte) 0x4d, (byte) 0x41, (byte) 0x00, (byte) 0x00, (byte) 0xb1, (byte) 0x8e, (byte) 0x7c, (byte) 0xfb, (byte) 0x51, (byte) 0x93, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x20, (byte) 0x63, (byte) 0x48, (byte) 0x52, (byte) 0x4d, (byte) 0x00, (byte) 0x00, (byte) 0x7a, (byte) 0x25, (byte) 0x00, (byte) 0x00, (byte) 0x80, (byte) 0x83, (byte) 0x00, (byte) 0x00, (byte) 0xf9, (byte) 0xff, (byte) 0x00, (byte) 0x00, (byte) 0x80, (byte) 0xe6, (byte) 0x00, (byte) 0x00, (byte) 0x75,
        (byte) 0x2e, (byte) 0x00, (byte) 0x00, (byte) 0xea, (byte) 0x5f, (byte) 0x00, (byte) 0x00, (byte) 0x3a, (byte) 0x97, (byte) 0x00, (byte) 0x00, (byte) 0x17, (byte) 0x6f, (byte) 0x69, (byte) 0xe4, (byte) 0xc4, (byte) 0x2b, (byte) 0x00, (byte) 0x00, (byte) 0x03, (byte) 0x00, (byte) 0x50, (byte) 0x4c, (byte) 0x54, (byte) 0x45, (byte) 0xe6, (byte) 0xe6, (byte) 0xe6, (byte) 0xcc, (byte) 0xcc, (byte) 0xcc, (byte) 0x7d, (byte) 0x7d, (byte) 0x7d, (byte) 0xff, (byte) 0xff, (byte) 0xff, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0xa0, (byte) 0xe5, (byte) 0xcc, (byte) 0x14, (byte) 0x00,
        (byte) 0x00, (byte) 0x00, (byte) 0x04, (byte) 0x74, (byte) 0x52, (byte) 0x4e, (byte) 0x53, (byte) 0xff, (byte) 0xff, (byte) 0xff, (byte) 0x00, (byte) 0x40, (byte) 0x2a, (byte) 0xa9, (byte) 0xf4, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x60, (byte) 0x49, (byte) 0x44, (byte) 0x41, (byte) 0x54, (byte) 0x78, (byte) 0x9c, (byte) 0x62, (byte) 0x60, (byte) 0x06, (byte) 0x03, (byte) 0x46, (byte) 0x08, (byte) 0x05, (byte) 0x10, (byte) 0x40, (byte) 0x0c, (byte) 0x10, (byte) 0x0e, (byte) 0x03,
        (byte) 0x13, (byte) 0x98, (byte) 0x06, (byte) 0x08, (byte) 0x20, (byte) 0x06, (byte) 0x08, (byte) 0x87, (byte) 0x01, (byte) 0xc2, (byte) 0x05, (byte) 0x08, (byte) 0x20, (byte) 0x06, (byte) 0x28, (byte) 0x07, (byte) 0xc2, (byte) 0x05, (byte) 0x08, (byte) 0x20, (byte) 0x06, (byte) 0x18, (byte) 0x07, (byte) 0xcc, (byte) 0x05, (byte) 0x08, (byte) 0x20, (byte) 0x06, (byte) 0x38, (byte) 0x07, (byte) 0xc4, (byte) 0x05, (byte) 0x08, (byte) 0x20, (byte) 0x06, (byte) 0x46, (byte) 0x26, (byte) 0x26,
        (byte) 0x26, (byte) 0xb0, (byte) 0x3e, (byte) 0x10, (byte) 0x00, (byte) 0x08, (byte) 0x20, (byte) 0x54, (byte) 0x53, (byte) 0x00, (byte) 0x02, (byte) 0x08, (byte) 0x95, (byte) 0x07, (byte) 0x10, (byte) 0x40, (byte) 0xa8, (byte) 0x3c, (byte) 0x80, (byte) 0x00, (byte) 0x42, (byte) 0xe5, (byte) 0x01, (byte) 0x04, (byte) 0x10, (byte) 0x2a, (byte) 0x0f, (byte) 0x20, (byte) 0x80, (byte) 0x20, (byte) 0x3c, (byte) 0x90, (byte) 0x79, (byte) 0x20, (byte) 0x06, (byte) 0x40, (byte) 0x80, (byte) 0x01,
        (byte) 0x00, (byte) 0x74, (byte) 0xd7, (byte) 0x01, (byte) 0x49, (byte) 0x4a, (byte) 0xc4, (byte) 0x00, (byte) 0x8f, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x49, (byte) 0x45, (byte) 0x4e, (byte) 0x44, (byte) 0xae, (byte) 0x42, (byte) 0x60, (byte) 0x82
    };

    private byte[] cn = {
        (byte) 0x89, (byte) 0x50, (byte) 0x4e, (byte) 0x47, (byte) 0x0d, (byte) 0x0a, (byte) 0x1a, (byte) 0x0a, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x0d, (byte) 0x49, (byte) 0x48, (byte) 0x44, (byte) 0x52, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x0d, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x0d, (byte) 0x08, (byte) 0x02, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0xfd, (byte) 0x89, (byte) 0x73, (byte) 0x2b, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x01, (byte) 0x73,
        (byte) 0x52, (byte) 0x47, (byte) 0x42, (byte) 0x00, (byte) 0xae, (byte) 0xce, (byte) 0x1c, (byte) 0xe9, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x04, (byte) 0x67, (byte) 0x41, (byte) 0x4d, (byte) 0x41, (byte) 0x00, (byte) 0x00, (byte) 0xb1, (byte) 0x8f, (byte) 0x0b, (byte) 0xfc, (byte) 0x61, (byte) 0x05, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x20, (byte) 0x63, (byte) 0x48, (byte) 0x52, (byte) 0x4d, (byte) 0x00, (byte) 0x00, (byte) 0x7a, (byte) 0x26, (byte) 0x00, (byte) 0x00,
        (byte) 0x80, (byte) 0x84, (byte) 0x00, (byte) 0x00, (byte) 0xfa, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x80, (byte) 0xe8, (byte) 0x00, (byte) 0x00, (byte) 0x75, (byte) 0x30, (byte) 0x00, (byte) 0x00, (byte) 0xea, (byte) 0x60, (byte) 0x00, (byte) 0x00, (byte) 0x3a, (byte) 0x98, (byte) 0x00, (byte) 0x00, (byte) 0x17, (byte) 0x70, (byte) 0x9c, (byte) 0xba, (byte) 0x51, (byte) 0x3c, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x33, (byte) 0x49, (byte) 0x44, (byte) 0x41, (byte) 0x54,
        (byte) 0x28, (byte) 0x53, (byte) 0x63, (byte) 0xfc, (byte) 0xff, (byte) 0xff, (byte) 0x3f, (byte) 0x03, (byte) 0x31, (byte) 0x00, (byte) 0xa8, (byte) 0x0e, (byte) 0x0d, (byte) 0x00, (byte) 0x75, (byte) 0x61, (byte) 0x11, (byte) 0x24, (byte) 0x4d, (byte) 0x1d, (byte) 0x1e, (byte) 0x9b, (byte) 0x21, (byte) 0x06, (byte) 0x41, (byte) 0xad, (byte) 0x40, (byte) 0xb6, (byte) 0x0b, (byte) 0x2b, (byte) 0x7b, (byte) 0xe0, (byte) 0xd5, (byte) 0xe1, (byte) 0xf2, (byte) 0x0a, (byte) 0x8a, (byte) 0x3f,
        (byte) 0x90, (byte) 0x43, (byte) 0x87, (byte) 0x1a, (byte) 0xe1, (byte) 0x47, (byte) 0x35, (byte) 0xf3, (byte) 0x00, (byte) 0x1d, (byte) 0x23, (byte) 0x69, (byte) 0xa6, (byte) 0xf7, (byte) 0x74, (byte) 0x7d, (byte) 0x20, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x49, (byte) 0x45, (byte) 0x4e, (byte) 0x44, (byte) 0xae, (byte) 0x42, (byte) 0x60, (byte) 0x82
    };
}

/* */
